@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,7 +28,6 @@ class PimCommon::RichTextEditWithAutoCorrectionPrivate
 public:
     RichTextEditWithAutoCorrectionPrivate()
         : mAutoCorrection(new PimCommon::AutoCorrection())
-        , mNeedToDelete(true)
     {
     }
 
@@ -39,7 +39,7 @@ public:
     }
 
     PimCommon::AutoCorrection *mAutoCorrection = nullptr;
-    bool mNeedToDelete = false;
+    bool mNeedToDelete = true;
 };
 
 RichTextEditWithAutoCorrection::RichTextEditWithAutoCorrection(QWidget *parent)
