@@ -1,9 +1,10 @@
 /*
- * Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
+ * Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License
+ *  This program is free software; you can redistribute it and/or modify it
+ *  under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -48,24 +49,23 @@ class Q_DECL_HIDDEN PimCommon::RenameFileDialog::RenameFileDialogPrivate
 {
 public:
     RenameFileDialogPrivate(const QUrl &_url, RenameFileDialog *qq)
-        : url(_url),
-          applyAll(nullptr),
-          rename(nullptr),
-          suggestNewName(nullptr),
-          nameEdit(nullptr),
-          q(qq)
+        : url(_url)
+        , applyAll(nullptr)
+        , renameBtn(nullptr)
+        , suggestNewNameBtn(nullptr)
+        , nameEdit(nullptr)
+        , q(qq)
     {
-
     }
+
     QString suggestName(const QUrl &baseURL, const QString &oldName);
 
     QUrl url;
-    QCheckBox *applyAll;
-    QPushButton *rename;
-    QPushButton *suggestNewName;
-    QLineEdit *nameEdit;
-    RenameFileDialog *q;
-
+    QCheckBox *applyAll = nullptr;
+    QPushButton *renameBtn = nullptr;
+    QPushButton *suggestNewNameBtn = nullptr;
+    QLineEdit *nameEdit = nullptr;
+    RenameFileDialog *q = nullptr;
 };
 
 QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const QUrl &baseURL, const QString &oldName)
@@ -118,12 +118,11 @@ QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const
     } else { // already exists -> recurse
         return suggestName(baseURL, suggestedName);
     }
-
 }
 
 RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *parent)
-    : QDialog(parent),
-      d(new RenameFileDialogPrivate(url, this))
+    : QDialog(parent)
+    , d(new RenameFileDialogPrivate(url, this))
 {
     setWindowTitle(i18n("File Already Exists"));
     QVBoxLayout *pLayout = new QVBoxLayout(this);
@@ -138,9 +137,9 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     renameLayout->addWidget(d->nameEdit);
     d->nameEdit->setClearButtonEnabled(true);
     d->nameEdit->setText(url.fileName());
-    d->suggestNewName = new QPushButton(i18n("Suggest New &Name"), this);
-    renameLayout->addWidget(d->suggestNewName);
-    connect(d->suggestNewName, &QPushButton::clicked, this, &RenameFileDialog::slotSuggestNewNamePressed);
+    d->suggestNewNameBtn = new QPushButton(i18n("Suggest New &Name"), this);
+    renameLayout->addWidget(d->suggestNewNameBtn);
+    connect(d->suggestNewNameBtn, &QPushButton::clicked, this, &RenameFileDialog::slotSuggestNewNamePressed);
 
     QPushButton *overWrite = new QPushButton(this);
     KStandardGuiItem::assign(overWrite, KStandardGuiItem::Overwrite);
@@ -149,8 +148,8 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     QPushButton *ignore = new QPushButton(i18n("&Ignore"), this);
     connect(ignore, &QPushButton::clicked, this, &RenameFileDialog::slotIgnorePressed);
 
-    d->rename = new QPushButton(i18n("&Rename"), this);
-    connect(d->rename, &QPushButton::clicked, this, &RenameFileDialog::slotRenamePressed);
+    d->renameBtn = new QPushButton(i18n("&Rename"), this);
+    connect(d->renameBtn, &QPushButton::clicked, this, &RenameFileDialog::slotRenamePressed);
 
     KSeparator *separator = new KSeparator(this);
     pLayout->addWidget(separator);
@@ -164,7 +163,7 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
         layout->addWidget(d->applyAll);
         slotApplyAllPressed();
     }
-    layout->addWidget(d->rename);
+    layout->addWidget(d->renameBtn);
     layout->addWidget(overWrite);
     layout->addWidget(ignore);
 }
@@ -218,8 +217,8 @@ void RenameFileDialog::slotApplyAllPressed()
 {
     const bool enabled(!d->applyAll->isChecked());
     d->nameEdit->setEnabled(enabled);
-    d->suggestNewName->setEnabled(enabled);
-    d->rename->setEnabled(enabled);
+    d->suggestNewNameBtn->setEnabled(enabled);
+    d->renameBtn->setEnabled(enabled);
 }
 
 void RenameFileDialog::slotSuggestNewNamePressed()
@@ -241,4 +240,3 @@ QUrl RenameFileDialog::newName() const
 
     return newDest;
 }
-
