@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,22 +34,21 @@ public:
     SelectMultiCollectionDialogPrivate()
         : mSelectMultiCollection(nullptr)
     {
-
     }
 
-    SelectMultiCollectionWidget *mSelectMultiCollection;
+    SelectMultiCollectionWidget *mSelectMultiCollection = nullptr;
 };
 
 SelectMultiCollectionDialog::SelectMultiCollectionDialog(const QString &mimetype, const QList<Akonadi::Collection::Id> &selectedCollection, QWidget *parent)
-    : QDialog(parent),
-      d(new PimCommon::SelectMultiCollectionDialogPrivate)
+    : QDialog(parent)
+    , d(new PimCommon::SelectMultiCollectionDialogPrivate)
 {
     initialize(mimetype, selectedCollection);
 }
 
 SelectMultiCollectionDialog::SelectMultiCollectionDialog(const QString &mimetype, QWidget *parent)
-    : QDialog(parent),
-      d(new PimCommon::SelectMultiCollectionDialogPrivate)
+    : QDialog(parent)
+    , d(new PimCommon::SelectMultiCollectionDialogPrivate)
 {
     initialize(mimetype);
 }
@@ -95,4 +95,3 @@ QVector<Akonadi::Collection> SelectMultiCollectionDialog::selectedCollection() c
 {
     return d->mSelectMultiCollection->selectedCollection();
 }
-
