@@ -2,8 +2,9 @@
   Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -43,7 +44,7 @@ public:
 
     void setActionTypes(const QVector<ActionType> &type);
     void addActionType(const ActionType &type);
-    QVector<ActionType> actionTypes() const;
+    Q_REQUIRED_RESULT QVector<ActionType> actionTypes() const;
 
     virtual void setCurrentItems(const Akonadi::Item::List &items);
     virtual void setItems(const Akonadi::Item::List &items);
